#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class UserInfo(object):

	def __init__(self, rq):
        self.requester = rq

    def getUserInfoObjectByNetID(self,netid):
    	print "jhere"


	def getOwnUserInfo(self):
		